@@ -16,7 +16,7 @@ class LeagueInfo:
     :param week: the week of interest
     :type week: int, optional
     """
-    def __init__(self, sc, season=None, week=None):
+    def __init__(self, sc, season, week=None):
         self.sc = sc
         self.league_key = None
         self.league_id = None
@@ -43,6 +43,9 @@ class LeagueInfo:
         self.league = None
         self.roster_positions = None
         self.stat_categories = None
+        self.is_quarterfinals = False
+        self.is_semifinals = False
+        self.is_finals = False
         self._update_LeagueInfo()
 
     def get_weekly_matchups(self):
@@ -51,32 +54,50 @@ class LeagueInfo:
         """
         matchups_raw = yfa.League(self.sc, self.league_key).matchups(week=self.week)
         tree = objectpath.Tree(matchups_raw)
-        team_ids = list(map(int, list(tree.execute('$..team_id'))))
-        team_points_total = list(map(float, list(tree.execute('$..team_points.total'))))
-        win_probability = list(map(float, list(tree.execute('$..win_probability'))))
-        team_projected_points = list(map(float, list(tree.execute('$..team_projected_points.total'))))
+        matchups = list(tree.execute('$..matchup'))
 
         self.weekly_matchups = []
-        for i in range(self.num_matchups):
+        for matchup in matchups:
             wm = WeeklyMatchup()
+            tree = objectpath.Tree(matchup)
+            wm.is_playoffs = bool(int(list(tree.execute('$..is_playoffs'))[0]))
+            wm.is_consolation = bool(int(list(tree.execute('$..is_consolation'))[0]))
 
-            m_index = 2 * i
-            wm.manager_id = team_ids[m_index]
-            wm.manager_name = self.manager_names[wm.manager_id]
-            wm.manager_points_total = team_points_total[m_index]
-            wm.manager_win_probability = int(win_probability[m_index] * 100)
-            wm.manager_projected_points = team_projected_points[m_index]
-            # wm.manager_elo = dbq.get_manager_elo(self.season, self.week, wm.manager_name)
+            if wm.is_playoffs and wm.is_consolation:  # filter out consolation games for quarterfinals
+                pass
+            else:
+                team_ids = list(tree.execute('$..team_id'))
+                wm.manager_id = int(team_ids[0])
+                wm.opponent_id = int(team_ids[1])
 
-            o_index = 2 * i + 1
-            wm.opponent_id = team_ids[o_index]
-            wm.opponent_name = self.manager_names[wm.opponent_id]
-            wm.opponent_points_total = team_points_total[o_index]
-            wm.opponent_win_probability = int(win_probability[o_index] * 100)
-            wm.opponent_projected_points = team_projected_points[o_index]
-            # wm.opponent_elo = dbq.get_manager_elo(self.season, self.week, wm.opponent_name)
+                team_points_total = list(tree.execute('$..team_points.total'))
+                wm.manager_points_total = float(team_points_total[0])
+                wm.opponent_points_total = float(team_points_total[1])
 
-            self.weekly_matchups.append(wm)
+                win_probability = list(tree.execute('$..win_probability'))
+                wm.manager_win_probability = int(win_probability[0] * 100)
+                wm.opponent_win_probability = int(win_probability[1] * 100)
+
+                team_projected_points = list(tree.execute('$..team_projected_points.total'))
+                wm.manager_projected_points = float(team_projected_points[0])
+                wm.opponent_projected_points = float(team_projected_points[1])
+
+                wm.manager_name = self.manager_names[wm.manager_id]
+                wm.opponent_name = self.manager_names[wm.opponent_id]
+
+                wm.manager_curr_elo = dbq.get_current_elo(self.season, self.week, wm.manager_name)
+                wm.opponent_curr_elo = dbq.get_current_elo(self.season, self.week, wm.opponent_name)
+
+                is_fifth_place_matchup = False
+                if self.is_semifinals:
+                    quarter_finals = dbq.get_weekly_df(self.season, self.week - 1)
+                    quarter_finals = quarter_finals.drop(quarter_finals[quarter_finals.opponent_name == 'NULL'].index)
+                    quarter_finals = quarter_finals.manager_name.tolist()
+                    managers_to_check = [wm.manager_name, wm.opponent_name]
+                    is_fifth_place_matchup = set(managers_to_check).issubset(set(quarter_finals))
+                
+                if is_fifth_place_matchup is not True:
+                    self.weekly_matchups.append(wm)
 
     def get_weekly_matchup_histories(self):
         """Creates a list of historical matchup info objects for the main class
@@ -110,8 +131,8 @@ class LeagueInfo:
                 ".format(wm.manager_projected_points, wm.opponent_projected_points))
             print("  win prob | {:5d}%\t {:5d}% | win prob\
                 ".format(wm.manager_win_probability, wm.opponent_win_probability))
-            # print("   ranking | {:6d}\t {:6d} | ranking\
-            #     ".format(wm.manager_elo, wm.opponent_elo))
+            print("   ranking | {:6d}\t {:6d} | ranking\
+                ".format(wm.manager_curr_elo, wm.opponent_curr_elo))
             print("The current record between {} and {} is {} - {}. \
                 ".format(mh.manager_name, mh.opponent_name, mh.manager_wins, mh.opponent_wins))
             print("The average score between {} and {} is {:0.2f} - {:0.2f}.\
@@ -130,15 +151,6 @@ class LeagueInfo:
             except KeyError:  # not everyone's name is wrong so pass on the correct names
                 pass
 
-    def _get_current_season(self):
-        """Finds the current season from Yahoo if season isn't provided
-
-        :return: current season
-        :rtype: int
-        """
-        raw_game_data = yq.yahoo_query(self.sc, 'game/nfl')
-        return int(list(jq.search_json_key(raw_game_data, '..season'))[0])
-
     def _get_league_key_from_season(self):
         """Looks up league key specific for a specific season
 
@@ -160,6 +172,14 @@ class LeagueInfo:
         counts = map(int, list(tree.execute('$..roster_position.count')))
         return dict(zip(positions, counts))
 
+    def _check_for_playoffs(self):
+        if self.week - self.playoff_start_week == 0:
+            self.is_quarterfinals = True
+        elif self.week - self.playoff_start_week == 1:
+            self.is_semifinals = True
+        elif self.week - self.playoff_start_week == 2:
+            self.is_finals = True
+
     def _get_stats(self):
         """Gets stat categories and modifiers
 
@@ -201,10 +221,10 @@ class LeagueInfo:
         """Main method to update the LeagueInfo class with SIT data
 
         """
-        self.current_season = self._get_current_season()
+        # self.current_season = self._get_current_season()
 
-        if self.season is None:  # grab current season
-            self.season = self.current_season
+        # if self.season is None:  # grab current season
+        #     self.season = self.current_season
 
         self.league_key = self._get_league_key_from_season()
         self.league = yfa.League(self.sc, self.league_key)
@@ -221,7 +241,7 @@ class LeagueInfo:
         self.end_date = jq.search_json_key(settings, '.end_date')
         self.game_code = jq.search_json_key(settings, '.game_code')
         self.persistent_url = jq.search_json_key(settings, '.persistent_url')
-        self.playoff_start_week = jq.search_json_key(settings, '.playoff_start_week')
+        self.playoff_start_week = int(jq.search_json_key(settings, '.playoff_start_week'))
         self.trade_end_date = jq.search_json_key(settings, '.trade_end_date')
         self.sendbird_channel_url = jq.search_json_key(settings, '.sendbird_channel_url')
         self.roster_positions = self._get_roster_positions()
@@ -230,6 +250,7 @@ class LeagueInfo:
         if self.week is None:  # grab current week
             self.week = self.current_week
 
+        self._check_for_playoffs()
         self.get_manager_names()
         self.get_weekly_matchups()
         self.get_weekly_matchup_histories()
